<?php
/**
 * @version    CVS: 1.0.0
 * @package    Com_Resourcespace
 * @author     Resource Space <shoaibalam.augurs@gmail.com>
 * @copyright  2025 ResourceSpace
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined('_JEXEC') or die;
use Joomla\CMS\Factory;

jimport('joomla.application.component.controllerform');

/**
 * Resourcespace controller class.
 *
 * @since  1.6
 */
class ResourcespaceController extends \Joomla\CMS\MVC\Controller\FormController
{
    /**
     * Constructor
     *
     * @throws Exception
     */
    public function __construct()
    {
        $this->view_list = 'resourcespaces';
        parent::__construct();
    }

    public function search()
    {
        $input = Factory::getApplication()->input;
        $query = $input->getString('search_query', '');

        $results = ResourcespaceHelper::fetchSearchResults($query);

        Factory::getApplication()->setUserState('com_resourcespace.search_results', $results);

        $this->setRedirect(JRoute::_('index.php?option=com_resourcespace', false));
    }
    public function data()
    {
        // Your API logic for the GET request
        // Check if the request is a POST request
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            // Get the raw POST input
            $inputData = file_get_contents('php://input');

            // Decode the JSON string into a PHP array
            $data = json_decode($inputData, true);

            if (json_last_error() !== JSON_ERROR_NONE) {
                // If there is a JSON parsing error
                echo json_encode(['success' => false, 'error' => 'Invalid JSON data', 'msg' => 'Invalid JSON data']);
                exit;
            }

            // Extract the "selected_items" array
            $selectedItems = isset($data['selected_items']) ? $data['selected_items'] : [];

            if (empty($selectedItems)) {
                // If no selected items are passed
                echo json_encode(['success' => false, 'error' => 'No selected items', 'msg' => 'No selected items']);

                exit;
            }

            // Process the selected items
            $processedItems = [];
            foreach ($selectedItems as $item) {
                // Validate the ID and URL
                if (isset($item['id']) && isset($item['url'])) {
                    // Process each item (you can perform operations like saving to a database, etc.)
                    // Here, we're just adding them to an array for now
                    $results          = ResourcespaceHelper::saveImageFromUrl($item['url'], $item['name'], $item['id'], $item['extension']);
                    $processedItems[] = [
                        'id'      => $item['id'],
                        'url'     => $item['url'],
                        'results' => $results,
                    ];
                }
            }
            // Send the response as JSON
            echo json_encode(['success' => true, 'processed_items' => count($processedItems), 'msg' => 'Images updated/saved successfully']);
            exit;
        } else {
            echo json_encode(['success' => false, 'error' => 'Invalid request method']);
            exit;
        }

    }
}
