<?php
/**
 * @version    CVS: 1.0.0
 * @package    Com_Resourcespace
 * @author     Resource Space <shoaibalam.augurs@gmail.com>
 * @copyright  2025 ResourceSpace
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\MVC\Controller\BaseController;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use Joomla\CMS\Task\TaskRegistry;

// Access check.
if (!Factory::getUser()->authorise('core.manage', 'com_resourcespace'))
{
    throw new Exception(Text::_('JERROR_ALERTNOAUTHOR'));
}

// Include dependencies
jimport('joomla.application.component.controller');

JLoader::registerPrefix('Resourcespace', JPATH_COMPONENT_ADMINISTRATOR);
JLoader::register('ResourcespaceHelper', JPATH_COMPONENT_ADMINISTRATOR . DIRECTORY_SEPARATOR . 'helpers' . DIRECTORY_SEPARATOR . 'resourcespace.php');


// Ensure TaskRegistry is available before registering
if (class_exists(TaskRegistry::class)) {
    require_once JPATH_COMPONENT_ADMINISTRATOR . '/task/FetchResourceTask.php';
    TaskRegistry::registerTask(FetchResourceTask::class);
}
$input = Factory::getApplication()->input;
$task = $input->getCmd('task', 'display');



if ($task === 'api.data') {
    // Manually load the API controller
    require_once JPATH_COMPONENT_ADMINISTRATOR . '/controllers/resourcespace.php';
    $controller = new ResourcespaceController();
    $controller->data();  // Call the data method to handle the API request
    exit; // Exit after the API response is sent
}

if ($task === 'search') {
    require_once JPATH_COMPONENT_ADMINISTRATOR . '/controllers/resourcespace.php';
    $controller = new ResourcespaceController();
    $controller->search();
} else {
    $controller = BaseController::getInstance('Resourcespace');
}

$controller->execute($task);
$controller->redirect();
